"""
================================
binarymap
================================

Binary representations of protein or nucleotide sequences.

Importing this package imports the following objects
into the package namespace:

 - :py:mod:`binarymap.binarymap.BinaryMap`

"""

__author__ = "`the Bloom lab <https://research.fhcrc.org/bloom/en.html>`_"
__email__ = "jbloom@fredhutch.org"
__version__ = "0.5"
__url__ = "https://github.com/jbloomlab/binarymap"

from binarymap.binarymap import BinaryMap  # noqa: F401
